@@ -1,5 +1,5 @@
 import abc
-from typing import Optional, List, Dict
+from typing import Optional, List, Dict, Any
 import logging
 from cdocs.config import Config
 from cdocs.simple_config import SimpleConfig
@@ -7,50 +7,7 @@ from cdocs.simple_filer import SimpleFiler
 from cdocs.cdocs import Cdocs
 from cdocs.contextual_docs import Doc, DocPath, FilePath, JsonDict, ContextualDocs
 from cdocs.multi_context_docs import MultiContextDocs
-
-
-class ContextMetaData(object):
-
-    def __init__(self, config:Optional[Config]=None):
-        self._config = SimpleConfig() if config is None else config
-        self._roots:List[str] = [ _[1] for _ in self.config.get_items("docs")]
-        self._keyed_roots = { _[0]:_[1] for _ in self.config.get_items("docs")}
-        self._root_names = [ _[0] for _ in self.config.get_items("docs")]
-        self._accepts = {_[0]:[s for s in _[1].split(",")] for _ in self.config.get_items("accepts")}
-        self._accepted_by = dict()
-        for k in self._accepts:
-            v = self._accepts[k]
-            for av in v:
-                acceptors = self._accepted_by.get(av)
-                if acceptors is None:
-                    acceptors = []
-                acceptors.append(k)
-                self._accepted_by[av] = acceptors
-
-    @property
-    def accepted_by(self) -> Dict[str,List[str]]:
-        return self._accepted_by
-
-    @property
-    def accepts(self) -> Dict[str,List[str]]:
-        return self._accepts
-
-    @property
-    def roots(self) -> List[FilePath]:
-        return self._roots
-
-    @property
-    def root_names(self) -> List[str]:
-        return self._root_names
-
-    @property
-    def keyed_roots(self) -> Dict[str,FilePath]:
-        return self._keyed_roots
-
-    @property
-    def config(self) -> Config:
-        return self._config
-
+from cdocs.context_metadata import ContextMetadata
 
 class Context(ContextualDocs, MultiContextDocs):
     """
@@ -59,7 +16,7 @@ class Context(ContextualDocs, MultiContextDocs):
     get_labels is the exception in that it gets the union of all labels found
     in any of the Cdocs. The value of first use of a label name wins.
     """
-    def __init__(self, metadata:ContextMetaData):
+    def __init__(self, metadata:ContextMetadata):
         self._metadata = metadata
         self._keyed_cdocs = { k : Cdocs(v, metadata.config, self) for k,v in metadata.keyed_roots.items() }
         self._cdocs = [ v for k,v in self.keyed_cdocs.items() ]
@@ -73,7 +30,7 @@ class Context(ContextualDocs, MultiContextDocs):
         return self._keyed_cdocs
 
     @property
-    def metadata(self) -> ContextMetaData:
+    def metadata(self) -> ContextMetadata:
         return self._metadata
 
     # ==== ContextualDocs ==================
